#!/bin/sh

# A shell script to connect to a VMware Server VM using their perl API,
# take a snapshot,
# copy visual basic scripts used for setup and testing,
# and run the initial setup scripts.
# Copyright Brad Henry <brad@samba.org> 2006
# Released under the GNU GPL v2 or later.

. initial_setup.conf

vm_setup()
{
	echo -e "\nSetting up the windows environment." >> $STDOUT_REDIR
	perl vm_setup.pl >> $STDOUT_REDIR 2>> $STDERR_REDIR
	err_rtn=$?
}

display_output()
{
	cat $STDOUT_REDIR
	cat $STDERR_REDIR
}

remove_files()
{
	# If these redirect to special files, we won't delete them.
	for redir in $STDERR_REDIR \
			$STDOUT_REDIR
	do

		if [ ! -b $redir \
			-a ! -c $redir \
			-a ! -p $redir ]
			then
				rm -f $redir
		fi
	done
}

create_files()
{
	touch $STDOUT_REDIR
	touch $STDERR_REDIR
}

check_error()
{
	if [ $err_rtn -ne 0 ]
		then
			echo -e $err_str >> $err_redir
			# Report output recieved so far.
			display_output
			# Exit in error
			exit $err_rtn
		else
			echo -e $err_ok_str >> $err_redir
	fi
}

# If we crashed on a previous run, we want to know that our log files are clean.
remove_files

# Create the local log files.
create_files

# Connect to the VM, get the ip, take a snapshot,
# and run the initial windows configuration.
err_str="\nVM setup failed."
err_ok_str="\nVM setup completed successfully."
err_redir=$STDERR_REDIR
vm_setup
check_error

display_output
exit $err_rtn
